#!/usr/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
# (#) ./base/pm/adm/backupScenario.sh BL_core_schema_8.0.6.7.01_20100225  193759
#
SCRIPTNAME=`basename $0`

usage() 
{ 
 echo 'Usage:' 
 echo "$SCRIPTNAME  -f folder -s scenario" 
 echo '-f : The name of the folder where the scenario resides '
 echo '-s : The name of the scenario to Backup '
 echo '' 
 exit 2 
} 

if [ $# -eq 0 ]
 then
 usage
 exit 2
fi

SCENARIO=NULL
FOLDER=NULL

while [ $# -gt 0 ]
do

    case $1 in
      -f) 
          shift
          FOLDER=\'$1\'    
          ;;
      -s) 
          shift
          SCENARIO=\'$1\'    
          ;;
      -v) 
          usage
          ;;
       *) echo "$SCRIPTNAME: Invalid parameter "
          usage
          ;;
     esac

     if [ $# -gt 0 ]
      then
       shift
     fi
done

if [[ ${FOLDER:=NULL} = "NULL" ]]
 then
	usage
fi

if [[ ${SCENARIO:=NULL} = "NULL" ]]
 then
	usage
fi

sqlplus -s /NOLOG <<!
set linesize 1000
set serveroutput on size unlimited
set heading off
set verify off
set showmode off
set feedback off
connect $DBUSER/$DBPASSWD@$DBSID
variable retcode_sh NUMBER
DECLARE
  retcode number;
BEGIN
  wm_scenarioupdate.backupscenario(${FOLDER},${SCENARIO},retcode);
  :retcode_sh := retcode;
END;
/
EXIT :retcode_sh
!
retcode=$?
#Check exit code from sql process and exit accordingly
if [ $retcode = 0 ]
then
   echo "PL/SQL procedure wm_scenarioupdate.backupscenario completed for Folder ${FOLDER} Scenario = ${SCENARIO}"
   exit 0
else
   echo "Error calling PL/SQL procedure wm_scenarioupdate.backupscenario for FOLDER ${FOLDER} Scenario = ${SCENARIO}"
   exit 1
fi
