#!/usr/bin/ksh
###########################################################################
#
# Licensed Materials - Property of IBM
# 5724-T05,5724-T06
#
# (C) Copyright IBM Corp. 2003,2008. All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
###########################################################################
#
SCRIPTNAME=`basename $0`

usage()
{
 echo 'Usage:'
 echo "$SCRIPTNAME  -e entity_name -s scenario_name -f folder_name "
 echo '-e : The entity name of the instance'
 echo '-f : The name of the folder where the scenario resides'
 echo '-s : The name of the scenario'
 echo ''
 echo "Example:"
 echo $SCRIPTNAME ' -e RNC -f "\Scenarios" -s "ACTIVE-68-Raleigh UTRAN"'
 echo $SCRIPTNAME ' -e UtranCell -f "\Scenarios" -s "ACTIVE-68-Raleigh UTRAN"'
 echo ''
 exit 2
}

if [ $# -eq 0 ]
 then
 usage
 exit 2
fi

ENTITY=NULL
SCENARIO=NULL
FOLDER=NULL

while [ $# -gt 0 ]
do

    case $1 in
      -e)
          shift
          ENTITY=\'$1\'
          ;;
      -s)
          shift
          SCENARIO=\'$1\'
          ;;
      -f)
          shift
          FOLDER=\'$1\'
          ;;
      -v|-help)
          usage
          ;;
       *) echo "$SCRIPTNAME: Invalid parameter "
          usage
          ;;
     esac

     if [ $# -gt 0 ]
      then
       shift
     fi
done

if [ "${ENTITY:=NULL}" = "NULL" ]
 then
        usage
fi

if [ "${SCENARIO:=NULL}" = "NULL" ]
 then
        usage
fi

if [ "${FOLDER}" = "NULL" ]
 then
       usage
fi

# The folder path should have  "\" in the path. Convert "/" to "\" , if any 
FOLDER="$(echo $FOLDER | tr '/' '\\')"

echo "Entity: ${ENTITY}, Folder: ${FOLDER} Scenario: ${SCENARIO} "
entity_id=`sqlplus -s /NOLOG << END  | grep VAL |cut -f2 -d"="
set head off;
set feed off;
conn $DB_CONNECT
select 'VAL=' || entity_id from wmn_entity where entity_name= ${ENTITY};
END`

scenario_id=`sqlplus -s /NOLOG << END  | grep VAL |cut -f2 -d"="
set head off;
set feed off;
conn $DB_CONNECT
select 'VAL=' || id from pm_scenario where name= ${SCENARIO} and folderid= (select FS_LookupFolderByPath( ${FOLDER} ) from dual);
END`

sqlplus -s /NOLOG << END  | sort -t1-1 -n 
set pages 9999;
set feed off;
conn $DB_CONNECT
exec wm_dictionary_schema.parse_scenario(${scenario_id},${entity_id});
select fullkey from wmda_scenario_instance_tmp where fullkey like '%-%' order by fullkey ;
END
