set timing on;
set serveroutput on size 1000000;

BEGIN

   run_sql( ' ALTER TABLE part_tables '
         || ' ADD ( termination_date date )' );

   run_sql( ' ALTER TABLE part_task '
         || ' ADD ( termination_date date )' );

   run_sql( ' CREATE TABLE WM_MESSAGE_LOG '
         || ' (MESSAGE_ID		INTEGER NOT NULL, TSTAMP DATE NOT NULL, COMPONENT VARCHAR2(60) NOT NULL, '
         || '  MESSAGE_TEXT 	VARCHAR2(1000) NOT NULL, SEVERITY VARCHAR2(10), '
         || '  CONSTRAINT 		PK_WM_LOG_MESSAGE PRIMARY KEY (TSTAMP, MESSAGE_ID), '
         || '  CONSTRAINT 		CK_WM_LOG_MESSAGE_SEV CHECK (SEVERITY IN (''HIGH'',''MEDIUM'',''LOW'')) ENABLE '
         || ' ) ORGANIZATION INDEX PARTITION BY RANGE(tstamp) '
         || '( PARTITION ' || 'P' || TO_CHAR(trunc(sysdate+1), 'YYYYMMDDHH24')
         || ' VALUES LESS THAN (TO_DATE(''' || TO_CHAR(trunc(sysdate+2), 'YYYYMMDDHH24') || ''', ''YYYYMMDDHH24'')) ) '
         || ' TABLESPACE TRAFFIC_MEDIUM' );

   run_sql( ' CREATE SEQUENCE  wm_log_message_seq  MINVALUE 1 NOMAXVALUE INCREMENT BY 1 START WITH 1 CACHE 100 NOORDER  NOCYCLE ' );

   run_sql( 'CREATE INDEX ind_Instance_Entity_subtype ON wmn_Instance ( Entity_ID, SubType_ID ) '
         || 'tablespace wm_flexpm' );

   run_sql( 'CREATE INDEX inst_cxt_instance_id ON wmn_Instance_Context '
         || '    (Instance_Id) '
         || '    TABLESPACE wm_flexpm STORAGE (FREELISTS 4) ' );

   run_sql( 'CREATE INDEX inst_cxt_entity_id ON wmn_Instance_Context '
         || '    (entity_Id) '
         || '    TABLESPACE wm_flexpm STORAGE (FREELISTS 4) ' );


   DELETE FROM EDS_PRIMARYKEY e
    WHERE NOT EXISTS (SELECT 1 FROM wmd_field_def f where f.field_id = e.field_id);
   COMMIT;

   run_sql( ' ALTER TABLE EDS_PRIMARYKEY ENABLE CONSTRAINT FK_EDS_PMRYKEYFIELD_ID ' );

   DELETE FROM PEIK_EXTRA_FLD_PROPERTY e
    WHERE NOT EXISTS (SELECT 1 FROM wmd_field_def f where f.field_id = e.field_id);
   COMMIT;

   run_sql( ' ALTER TABLE PEIK_EXTRA_FLD_PROPERTY ENABLE CONSTRAINT FK_PEIK_EXTRA_FLD_PRPT_FLD_ID ' );

   DELETE FROM PM_REPORTGROUPING e
    WHERE NOT EXISTS (SELECT 1 FROM wmd_field_def f where f.field_id = e.field_id);
   COMMIT;

   run_sql( ' ALTER TABLE PM_REPORTGROUPING ENABLE CONSTRAINT FK_PM_RPTGRPING_FIELD_ID ' );

   DELETE FROM WMD_EDS_DEF e
    WHERE NOT EXISTS (SELECT 1 FROM wmd_field_def f where f.field_id = e.field_id);
   COMMIT;
    
   run_sql( ' ALTER TABLE WMD_EDS_DEF ENABLE CONSTRAINT FK_EDSDEF_FLDID ' );

   DELETE FROM WMD_FIELD_STYLE e
    WHERE NOT EXISTS (SELECT 1 FROM wmd_field_def f where f.field_id = e.field_id);
   COMMIT;

   run_sql( ' ALTER TABLE WMD_FIELD_STYLE ENABLE CONSTRAINT WMD_FIELD_STYLE_C1 ' );

   DELETE FROM WMD_UDC_RENAMEHIST e
    WHERE NOT EXISTS (SELECT 1 FROM wmd_field_def f where f.field_id = e.field_id);
   COMMIT;

   run_sql( ' ALTER TABLE WMD_UDC_RENAMEHIST ENABLE CONSTRAINT UDC_RENAME_FLD_FKY ' );

   DELETE FROM WMD_UDR_KEYS e
    WHERE NOT EXISTS (SELECT 1 FROM wmd_field_def f where f.field_id = e.field_id);
   COMMIT;

   run_sql( ' ALTER TABLE WMD_UDR_KEYS ENABLE CONSTRAINT UDRKEY_FIELD_FKY ' );

   run_sql( ' alter table task_status move tablespace wm_flexpm ' );
   run_sql( ' alter table active_task move tablespace wm_flexpm ' );
   run_sql( ' alter table active_job move tablespace wm_flexpm ' );
   run_sql( ' alter index pk_active_job rebuild ' );
   run_sql( ' alter index pk_active_task rebuild ' );
   run_sql( ' alter index active_task_unq rebuild ' );
   run_sql( ' alter index task_status_unq rebuild ' );
   run_sql( ' alter index task_status_unq_task rebuild ' );
   run_sql( ' alter index task_status_job rebuild ' );

   run_sql( ' CREATE INDEX IDX_RG_SNAP_RPT_ATTR_TASKID ON RG_SNAP_REPORT_ATTR(task_id) ' );
   run_sql( ' alter table rg_dtscope drop constraint fk_rg_dtscope ' );
   run_sql( ' alter table rg_trunc drop constraint fk_rg_trunc_tid ' );
   run_sql( ' alter table rg_tstamp_range drop constraint fk_rg_tstamp_range_tid ' );
   run_sql( ' alter table rg_scenario drop constraint fk_rg_scenario ' );
   run_sql( ' alter table rg_scenario_remap drop constraint fk_rg_scenario_remap ' );
   run_sql( ' alter table rg_instance_tree_mv drop constraint fk_rg_instance_tree_mv ' );
   run_sql( ' alter table rg_busyhour_mv drop constraint fk_rg_busyhour_mv ' );

END;
/

